<?php
/**
 * thebis Theme Customizer
 *
 * @package thebis
 */


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */


function thebis_customize_register( $wp_customize ) {
	
	// thebis theme choice options
    if (!function_exists('thebis_section_choice_option')) :
        function thebis_section_choice_option()
        {
            $thebis_section_choice_option = array(
                'show' => esc_html__('Show', 'thebis'),
                'hide' => esc_html__('Hide', 'thebis')
            );
            return apply_filters('thebis_section_choice_option', $thebis_section_choice_option);
        }
    endif;


    if (!function_exists('thebis_column_layout_option')) :
        function thebis_column_layout_option()
        {
            $thebis_column_layout_option = array(
                '6' => esc_html__('2 Column Layout', 'thebis'),
                '4' => esc_html__('3 Column Layout', 'thebis'),
                '3' => esc_html__('4 Column Layout', 'thebis'),
            );
            return apply_filters('thebis_column_layout_option', $thebis_column_layout_option);
        }
    endif;



    /**
     * Sanitizing the select callback example
     *
    */
    if ( !function_exists('thebis_sanitize_select') ) :
        function thebis_sanitize_select( $input, $setting ) {

            // Ensure input is a slug.
            $input = sanitize_text_field( $input );

            // Get list of choices from the control associated with the setting.
            $choices = $setting->manager->get_control( $setting->id )->choices;

                // If the input is a valid key, return it; otherwise, return the default.
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }
    endif;


    if ( !function_exists('thebis_column_layout_sanitize_select') ) :
        function thebis_column_layout_sanitize_select( $input, $setting ) {

            // Ensure input is a slug.
            $input = sanitize_text_field( $input );

            // Get list of choices from the control associated with the setting.
            $choices = $setting->manager->get_control( $setting->id )->choices;

            // If the input is a valid key, return it; otherwise, return the default.
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }
    endif;
    
    /**
     * Drop-down Pages sanitization callback example.
     *
     * - Sanitization: dropdown-pages
     * - Control: dropdown-pages
     * 
     * Sanitization callback for 'dropdown-pages' type controls. This callback sanitizes `$page_id`
     * as an absolute integer, and then validates that $input is the ID of a published page.
     * 
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     * @see get_post_status() https://developer.wordpress.org/reference/functions/get_post_status/
     *
     * @param int                  $page    Page ID.
     * @param WP_Customize_Setting $setting Setting instance.
     * @return int|string Page ID if the page is published; otherwise, the setting default.
     */

    function thebis_sanitize_dropdown_pages( $page_id, $setting ) {
        // Ensure $input is an absolute integer.
        $page_id = absint( $page_id );
    
        // If $page_id is an ID of a published page, return it; otherwise, return the default.
        return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
    }


	
    /** Front Page Section Settings starts **/	

    $wp_customize->add_panel('frontpage', 
        array(
            'title'       => esc_html__('thebis Options', 'thebis'),        
		    'description' => '',                                        
		     'priority'   => 3,
        )
    );
	

    /** Header Section Settings Start **/

    $wp_customize->add_section('thebis_header_info', 
        array(
            'title'       => esc_html__('Header Section', 'thebis'),
            'description' => '',
            'panel'       => 'frontpage',
            'priority'    => 100
        )
    );
  
    $wp_customize->add_setting(
    'thebis_header_section_hideshow',
    array(
        'default'           => 'hide',
        'sanitize_callback' => 'thebis_sanitize_select',
    )
    );

    $thebis_header_section_hide_show_option = thebis_section_choice_option();

    $wp_customize->add_control('thebis_header_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Header Option', 'thebis'),
            'description' => esc_html__('Show/hide option for Header Section.', 'thebis'),
            'section'     => 'thebis_header_info',
            'choices'     => $thebis_header_section_hide_show_option,
            'priority'    => 1
        )
    );
  
  
   
  
  
    $wp_customize->add_setting('thebis_ctah_btn_url', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );


    $wp_customize->add_control('thebis_ctah_btn_url', 
        array(
            'label'    => esc_html__('Quote URL', 'thebis'),
            'section'  => 'thebis_header_info',
            'priority' => 3
        )
    );

    $wp_customize->add_setting('thebis_ctah_btn_text',
         array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('thebis_ctah_btn_text',
        array(
            'label'    => esc_html__('quote Text', 'thebis'),
            'section'  => 'thebis_header_info',
            'priority' => 4
        )
    );	

 /** Header Section Settings end **/

 /** Slider Section Settings Start **/

    // Panel - Slider Section 1
    $wp_customize->add_section('thebis_sliderinfo', 
        array(
            'title'       => esc_html__('Home Slider Section', 'thebis'),
            'description' => '',
            'panel'       => 'frontpage',
             'priority'   => 130
        )
    );

    // hide show
    
    $wp_customize->add_setting('thebis_slider_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'thebis_sanitize_select',
        )
    );

    $thebis_slider_section_hide_show_option = thebis_section_choice_option();

    $wp_customize->add_control('thebis_slider_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Slider Option', 'thebis'),
            'description' => esc_html__('Show/hide option for Slider Section.', 'thebis'),
            'section'     => 'thebis_sliderinfo',
            'choices'     => $thebis_slider_section_hide_show_option,
            'priority'    => 1
        )
    );
  
    $slider_no = 3;
        for( $i = 1; $i <= $slider_no; $i++ ) {
            $thebis_slider_page   = 'thebis_slider_page_' .$i;
            $thebis_slider_btntxt = 'thebis_slider_btntxt_' . $i;
            $thebis_slider_btnurl = 'thebis_slider_btnurl_' .$i;
            $thebis_slider_btntxt2 = 'thebis_slider_btntxt2_' . $i;
            $thebis_slider_btnurl2 = 'thebis_slider_btnurl2_' .$i;


    $wp_customize->add_setting( $thebis_slider_page,
        array(
            'default'           => 1,
            'sanitize_callback' => 'thebis_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( $thebis_slider_page,
        array(
            'label'     => esc_html__( 'Slider Page ', 'thebis' ) .$i,
            'section'   => 'thebis_sliderinfo',
            'type'      => 'dropdown-pages',
            'priority'  => 100,
        )
    );


    $wp_customize->add_setting( $thebis_slider_btntxt,
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( $thebis_slider_btntxt,
        array(
            'label'        => esc_html__( 'Button - Text','thebis' ),
            'section'      => 'thebis_sliderinfo',
            'type'         => 'text',
            'priority'     => 100,
        )
    );
        
    $wp_customize->add_setting( $thebis_slider_btnurl,
        array(
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control( $thebis_slider_btnurl,
        array(
            'label'       => esc_html__( 'Button - URL', 'thebis' ),
            'section'     => 'thebis_sliderinfo',
            'type'        => 'text',
            'priority'    => 100,
        )
    );


$wp_customize->add_setting( $thebis_slider_btntxt2,
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( $thebis_slider_btntxt2,
        array(
            'label'        => esc_html__( 'Button - Text2','thebis' ),
            'section'      => 'thebis_sliderinfo',
            'type'         => 'text',
            'priority'     => 100,
        )
    );
        
    $wp_customize->add_setting( $thebis_slider_btnurl2,
        array(
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control( $thebis_slider_btnurl2,
        array(
            'label'       => esc_html__( 'Button - URL2', 'thebis' ),
            'section'     => 'thebis_sliderinfo',
            'type'        => 'text',
            'priority'    => 100,
        )
    );

                
    }	
    /** About Section Settings  **/

$wp_customize->add_section('thebis_about_info', array(
      'title'   => __('Home About Section', 'thebis'),
      'description' => '',
    'panel' => 'frontpage',
      'priority'    => 130
    ));
  
  $wp_customize->add_setting(
    'thebis_aboutus_section_hideshow',
    array(
        'default' => 'hide',
        'sanitize_callback' => 'thebis_sanitize_select',
    )
    );
    $thebis_a_section_hide_show_option =thebis_section_choice_option();
    $wp_customize->add_control(
    'thebis_aboutus_section_hideshow',
    array( 
        'type' => 'radio',
        'label' => esc_html__('Show/hide option for About Us Section.', 'thebis'),
        'description' => '',
        'section' => 'thebis_about_info',
        'choices' => $thebis_a_section_hide_show_option,
        'priority' => 1
    )
    );
  
  $about_no = 1;
  for( $i = 1; $i <= $about_no; $i++ ) {
  $thebis_about_page = 'thebis_about_page_' . $i; 

    $wp_customize->add_setting( $thebis_about_page,
      array(
        'default'           => 1,
        'sanitize_callback' => 'thebis_sanitize_dropdown_pages',
      )
    );

$wp_customize->add_setting('thebis_about_title', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );


    $wp_customize->add_control('thebis_about_title',
        array(
           'label'    => esc_html__('Title', 'thebis'),
           'section'  => 'thebis_about_info',
           'priority' => 1
        )
    );


    $wp_customize->add_control( $thebis_about_page,
      array(
        'label'         => esc_html__( 'about page ', 'thebis' ).$i,
        'section'       => 'thebis_about_info',
        'type'          => 'dropdown-pages',
        'priority'      => 1,
      )
    );

   
  
  }



    /** Service Section Settings Start **/

	$wp_customize->add_section('thebis_services',              
        array(
            'title'       => esc_html__('Home Service Section', 'thebis'),          
            'description' => '',             
            'panel'       => 'frontpage',      
            'priority'    => 140,
        )
    );
    
    $wp_customize->add_setting('thebis_services_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'thebis_sanitize_select',
        )
    );

    $thebis_services_section_hide_show_option = thebis_section_choice_option();

    $wp_customize->add_control(
        'thebis_services_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Services Option', 'thebis'),
            'description' => esc_html__('Show/hide option Section.', 'thebis'),
            'section'     => 'thebis_services',
            'choices'     => $thebis_services_section_hide_show_option,
            'priority'    => 1
        )
    );


    // Services title
    $wp_customize->add_setting('thebis_services_title', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );


    $wp_customize->add_control('thebis_services_title',
        array(
           'label'    => esc_html__('service Title', 'thebis'),
           'section'  => 'thebis_services',
           'priority' => 1
        )
    );

  


    // Services 
   
    $service_no = 6;
        for( $i = 1; $i <= $service_no; $i++ ) {
            $thebis_servicepage = 'thebis_service_page_' . $i;
            $thebis_serviceicon = 'thebis_page_service_icon_' . $i;
        
    // Setting - Feature Icon
    $wp_customize->add_setting( $thebis_serviceicon,
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( $thebis_serviceicon,
        array(
            'label'         => esc_html__( 'Service Icon ', 'thebis' ).$i,
            'description'   =>  __('Select a icon in this list <a target="_blank" href="https://fontawesome.com/v4.7.0/icons/">Font Awesome icons</a> and enter the class name','thebis'),
            'section'       => 'thebis_services',
            'type'          => 'text',
            'priority'      => 100,
        )
    );
        
    $wp_customize->add_setting( $thebis_servicepage,
        array(
            'default'           => 1,
            'sanitize_callback' => 'thebis_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( $thebis_servicepage,
        array(
            'label'        => esc_html__( 'Service Page ', 'thebis' ) .$i,
            'section'      => 'thebis_services',
            'type'         => 'dropdown-pages',
            'priority'     => 100,
        )
    );
    }
    /** Service Section Settings End **/

   

    /** Blog Section Settings Start **/

    $wp_customize->add_section('thebis_blog_info', 
        array(
            'title'       => esc_html__('Home Blog Section', 'thebis'),
            'description' => '',
            'panel'       => 'frontpage',
            'priority'    => 160
        )
     );
    
    $wp_customize->add_setting('thebis_blog_section_hideshow',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'thebis_sanitize_select',
        )
    );

    $thebis_blog_section_hide_show_option = thebis_section_choice_option();

    $wp_customize->add_control('thebis_blog_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Blog Option', 'thebis'),
            'description' => esc_html__('Show/hide option for Blog Section.', 'thebis'),
            'section'     => 'thebis_blog_info',
            'choices'     => $thebis_blog_section_hide_show_option,
            'priority'    => 1
        )
    );
    
    $wp_customize->add_setting('thebis_blog_title', 
         array(
            'default'            => '',
            'type'               => 'theme_mod',
            'sanitize_callback'  => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('thebis_blog_title', 
        array(
            'label'    => esc_html__('Blog Title', 'thebis'),
            'section'  => 'thebis_blog_info',
            'priority' => 1
        )
    );
    
   
    /** Blog Section Settings End **/

/**callout**/

$wp_customize->add_section(
        'thebis_footer_contact', 
        array(
            'title'   => esc_html__('Home Callout Section', 'thebis'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 170
        )
    );
    
    $wp_customize->add_setting(
        'thebis_contact_section_hideshow',
        array(
            'default' => 'hide',
            'sanitize_callback' => 'thebis_sanitize_select',
        )
    );

    $thebis_section_choice_option = thebis_section_choice_option();
    $wp_customize->add_control(
        'thebis_contact_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Home Callout', 'thebis'),
            'description' => esc_html__('Show/hide option for Footer Callout Section.', 'thebis'),
            'section' => 'thebis_footer_contact',
            'choices' => $thebis_section_choice_option,
            'priority' => 5
        )
    );

    $wp_customize->add_setting(
        'thebis_ctah_heading', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'thebis_ctah_heading', 
        array(
            'label'   => esc_html__('Callout Text', 'thebis'),
            'section' => 'thebis_footer_contact',
            'priority'  => 8
        )
    );

 
    $wp_customize->add_setting(
        'thebis_ctah_btn_url1', 
        array(
            'default'   =>'',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control(
        'thebis_ctah_btn_url1', 
        array(
            'label'   => esc_html__('Button URL', 'thebis'),
            'section' => 'thebis_footer_contact',
            'priority'  => 10
        )
    );

    $wp_customize->add_setting(
        'thebis_ctah_btn_text1', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'thebis_ctah_btn_text1', 
        array(
            'label'   => esc_html__('Button Text', 'thebis'),
            'section' => 'thebis_footer_contact',
            'priority'  => 12
        )
    );

    /** Footer Section Settings Start **/

	 $wp_customize->add_section('thebis_footer',
        array(
            'title'       => esc_html__('Footer Section', 'thebis'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 180
        )
    );
    $wp_customize->add_setting('thebis_footer_section_hideshow',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'thebis_sanitize_select',
        )
    );
    $thebis_footer_section_hide_show_option = thebis_section_choice_option();
    $wp_customize->add_control('thebis_footer_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Footer Option', 'thebis'),
            'description' => esc_html__('Show/hide option for Footer Section.', 'thebis'),
            'section'     => 'thebis_footer',
            'choices'     => $thebis_footer_section_hide_show_option,
            'priority'    => 1
        ) 
    );
    $wp_customize->add_setting('thebis_footer_text',
        array(
            'default'             => '',
            'type'                => 'theme_mod',
            'sanitize_callback'   => 'wp_kses_post'
        )
    );
    $wp_customize->add_control('thebis_footer_text',
        array(
            'label'    => esc_html__('Copyright', 'thebis'),
            'section'  => 'thebis_footer',
            'type'     => 'textarea',
            'priority' => 2
        )
    ); 
    $social_icon_no = 5;
    for( $i = 1; $i <= $social_icon_no; $i++ )
    {
        $thebis_social_icon_url = 'thebis_social_icon_url_' . $i;
        $wp_customize->add_setting( $thebis_social_icon_url, array(
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw'
        ));
        $wp_customize->add_control( $thebis_social_icon_url, 
            array(
                'label'             => esc_html__( 'Social icon ', 'thebis' ) .$i,
                'section'           => 'thebis_footer',
                'priority'          => 100
        ));
    }

    /** Footer Section Settings End **/

}
add_action( 'customize_register', 'thebis_customize_register' );

